@@ -1,8 +1,6 @@
 from ML_management.mlmanagement import mlmanagement
 
 set_experiment = mlmanagement.set_experiment
-get_experiment_by_name = mlmanagement.get_experiment_by_name
-search_runs = mlmanagement.search_runs
 start_run = mlmanagement.start_run
 log_model = mlmanagement.log_model
 log_metric = mlmanagement.log_metric
@@ -11,6 +9,11 @@ autolog = mlmanagement.autolog
 load_model = mlmanagement.load_model
 save_model = mlmanagement.save_model
 active_run = mlmanagement.active_run
-get_run = mlmanagement.get_run
 end_run = mlmanagement.end_run
+log_artifact = mlmanagement.log_artifact
+log_param = mlmanagement.log_param
+log_params = mlmanagement.log_params
+set_server_url = mlmanagement.set_server_url
+get_server_url = mlmanagement.get_server_url
+get_server_websocket_url = mlmanagement.get_server_websocket_url
 MlflowClient = mlmanagement.MlflowClient
