@@ -4,13 +4,14 @@ from inspect import formatannotation, getfullargspec
 
 from jsonschema import SchemaError
 from jsonschema.validators import Draft4Validator
+
 from ML_management.mlmanagement.jsonschema_exceptions import (
-    DictKeysMustBeStrings,
-    FunctionContainsVarArgs,
-    FunctionContainsVarKwArgs,
-    InvalidSchema,
-    NoAnnotation,
-    UnsupportedType,
+    DictKeysMustBeStringsError,
+    FunctionContainsVarArgsError,
+    FunctionContainsVarKwArgsError,
+    InvalidSchemaError,
+    NoAnnotationError,
+    UnsupportedTypeError,
 )
 
 JSON_SCHEMA_DRAFT = "http://json-schema.org/draft-04/schema#"
@@ -28,7 +29,7 @@ def __get_or_raise(type_name):
     if type_name in type_map:
         return copy(type_map[type_name])
     else:
-        raise UnsupportedType(annotation=type_name, supported_types=list(type_map.keys()))
+        raise UnsupportedTypeError(annotation=type_name, supported_types=list(type_map.keys()))
 
 
 def __is_optional(annotation):
@@ -50,7 +51,10 @@ def __get_json_schema_from_annotation(annotation):
             )  # Optional[int] translates to int, and the field is not required
         else:
             formatted_annotation = formatannotation(annotation)
-            annotation_name = formatted_annotation.partition("[")[0]  # this is the only way to reliably get annotation name (e.g. "List")
+
+            # this is the only way to reliably get annotation name (e.g. "List")
+            annotation_name = formatted_annotation.partition("[")[0]
+
             if annotation_name == "List":
                 return {
                     "type": "array",
@@ -60,9 +64,9 @@ def __get_json_schema_from_annotation(annotation):
                 key_annotation = annotation.__args__[0]
                 if hasattr(key_annotation, "__name__"):
                     if key_annotation.__name__ != "str":
-                        raise DictKeysMustBeStrings(annotation=formatted_annotation)
+                        raise DictKeysMustBeStringsError(annotation=formatted_annotation)
                 else:
-                    raise DictKeysMustBeStrings(annotation=formatted_annotation)
+                    raise DictKeysMustBeStringsError(annotation=formatted_annotation)
                 return {
                     "type": "object",
                     "additionalProperties": __get_json_schema_from_annotation(annotation.__args__[1]),
@@ -71,7 +75,7 @@ def __get_json_schema_from_annotation(annotation):
                 # Union might represent Optional, in this case it would
                 return {"anyOf": [__get_json_schema_from_annotation(ann) for ann in annotation.__args__]}
             else:
-                raise UnsupportedType(
+                raise UnsupportedTypeError(
                     annotation=formatannotation(annotation),
                     supported_types=list(type_map.keys()),
                 )
@@ -80,7 +84,7 @@ def __get_json_schema_from_annotation(annotation):
         if hasattr(annotation, "__name__"):
             return __get_or_raise(annotation.__name__)
     else:
-        raise UnsupportedType(
+        raise UnsupportedTypeError(
             annotation=formatannotation(annotation),
             supported_types=list(type_map.keys()),
         )
@@ -96,9 +100,9 @@ def infer_jsonschema(func):
         for arg, default in zip(spec.args[-len(spec.defaults) :], spec.defaults):
             pos_args_defaults[arg] = default
     if spec.varargs:
-        raise FunctionContainsVarArgs(function_name=func.__name__)
+        raise FunctionContainsVarArgsError(function_name=func.__name__)
     if spec.varkw:
-        raise FunctionContainsVarKwArgs(function_name=func.__name__)
+        raise FunctionContainsVarKwArgsError(function_name=func.__name__)
     schema = {
         "$schema": JSON_SCHEMA_DRAFT,
         "type": "object",
@@ -117,7 +121,7 @@ def infer_jsonschema(func):
     required = []
     for arg in all_args:
         if arg not in spec.annotations:
-            raise NoAnnotation(arg=arg)
+            raise NoAnnotationError(arg=arg)
 
         schema["properties"][arg] = __get_json_schema_from_annotation(spec.annotations[arg])
         if arg in all_defaults:
@@ -130,6 +134,6 @@ def infer_jsonschema(func):
     try:
         Draft4Validator.check_schema(schema)
     except SchemaError as err:
-        raise InvalidSchema(schema=schema, original_message=str(err))
+        raise InvalidSchemaError(schema=schema, original_message=str(err)) from None
 
     return schema
